==> nextcloud-app-tasks-0.14.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/ar.js <==
OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "المهام القادمة",
    "Important" : "مهم",
    "Today" : "اليوم",
    "Week" : "أسبوع",
    "All" : "الكل",
    "Current" : "الحالي",
    "Completed" : "مكتمل",
    "Tasks" : "المهام",
    "The Tasks app for Nextcloud" : "تطبيق المهام لـ نكست كلاود",
    "Default list" : "القائمة الإفتراضية",
    "Hidden" : "مخفي",
    "Visible" : "مرئيّ",
    "Automatic" : "تلقائي",
    "Share with users or groups" : "شارك مع مستخدمين او مجموعات",
    "No users or groups" : "لا يوجد مستخدمين أو مجموعات",
    "Can edit" : "يمكن تعديله",
    "Unshare with {displayName}" : "الغاء المشاركة مع {displayName}",
    "Edit" : "تعديل",
    "Copy private link" : "نسخ الرابط الخاص",
    "Copied" : "نُسخت ",
    "Cannot copy" : "لا يمكن النسخ",
    "Export" : "تصدير",
    "Delete" : "حذف ",
    "Unshare" : "إلغاء المشاركة",
    "Save" : "حفظ",
    "Calendar link copied to clipboard." : "تم نسخ رابط التقويم.",
    "Calendar link could not be copied to clipboard." : "لم نتمكن من نسخ رابط التقويم.",
    "The name \"{calendar}\" is already used." : "الإسم\"{calendar}\" يستخدم بالفعل.",
    "An empty name is not allowed." : "غير مسموح بإسم فارغ",
    "An error occurred, unable to delete the calendar." : "حدث خطأ، لا يمكن حذف التقويم.",
    "Trash bin" : "المهملات",
    "Name" : "الاسم",
    "Deleted" : "تم حذفه",
    "Restore" : "استعادة ",
    "Delete permanently" : "حذف بشكل دائم",
    "Empty trash bin" : "تفريغ سلة المهملات",
    "Untitled task" : "مهمة بدون اسم",
    "Untitled event" : "فعالية بدون اسم",
    "Untitled item" : "بند غير معنون",
    "Unknown calendar" : "تقويم غير معروف",
    "Select a calendar" : "اختر تقويم",
    "Set date" : "تعيين التاريخ",
    "Set time" : "تعيين الوقت",
    "Delete date" : "حذف التاريخ",
    "Click here to add a note." : "اضغط هنا لإضافة ملاحظة.",
    "Set value" : "تعيين القيمة",
    "Delete value" : "حذف القيمة",
    "Add this as a new tag" : "أضف هذا كوسم جديد",
    "Delete all completed tasks." : "حذف كل المهام المكتملة.",
    "Delete completed tasks." : "حذف المهام المكتملة.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "قد حذفت المهام المكتملة من \"{calendar}\".",
    "No errors" : "لا توجد أخطاء",
    "Open your browser console for more details" : "افتح مِعراض المتصفح للمزيد من التفاصيل",
    "Due date" : "تاريخ الانجاز",
    "Sort by due date and summary." : "افرز حسب التاريخ و الملخص.",
    "Created date" : "تاريخ الإنشاء",
    "Last modified" : "آخر تعديل",
    "Completed date" : "تاريخ الإكتمال",
    "Alphabetically" : "أبجديا",
    "Delete task" : "حذف المهمّة",
    "[Yesterday]" : "[امس]",
    "[Today]" : "[اليوم]",
    "[Tomorrow]" : "[الغد]",
    "L [at] LT" : "L [عند] LT",
    "Create a new task" : "أنشئ مهمّة جديدة",
    "Cancel" : "إلغاء",
    "Create task" : "أنشئ المهمّة",
    "Close" : "إغلاق",
    "Tomorrow" : "غدا",
    "New List" : "قائمة جديدة",
    "All day" : "اليوم بأكمله",
    "Edit title" : "تحرير العنوان",
    "Details" : "التفاصيل",
    "Notes" : "الملاحظات",
    "Reminders" : "تذكيرات",
    "Repeat" : "التكرار",
    "When shared show full event" : "عرض الحدث كاملاً عند مشاركته",
    "When shared show only busy" : "عرض مشغول عند مشاركة الحدث",
    "When shared hide this event" : "إخفاء الحدث عند مشاركته",
    "Canceled" : "ملغي",
    "[Due today]" : "[مستحق اليوم]",
    "[Due tomorrow]" : "[مطلوب غداً]",
    "[Due on] LL" : "[مستحق في] LL",
    "[Was due yesterday]" : "[كان مستحق بالأمس]",
    "[Was due on] LL" : "[كان مستحق في] LL",
    "[Was due today at] LT" : "[كان مستحق اليوم عند] LT",
    "[Due today at] LT" : "[مستحق اليوم عند] LT",
    "[Due tomorrow at] LT" : "[مطلوب غداً عند] LT",
    "[Due on] LL [at] LT" : "[مستحق في] LL [عند] LT",
    "[Was due yesterday at] LT" : "[كان مستحق بالأمس عند] LT",
    "[Was due on] LL [at] LT" : "[كان مستحق في] LL [عند] LT",
    "Set due date" : "تعيين تاريخ استحقاق",
    "{percent} % completed" : "{percent}% مكتمل",
    "No upcoming tasks" : "لا مهام قادمة ",
    "upcoming tasks" : "المهام القادمة",
    "No tasks today" : "لا مهام لليوم",
    "Mark as done" : "تمييز كمُنجز",
    "No due date assigned" : "لم يتم تعيين تاريخ استحقاق",
    "[Due yesterday]" : "[كان مستحق بالأمس]",
    "[Due] L" : "[مستحق في] L",
    "[Due yesterday at] LT" : "[كان مستحق بالأمس عند] LT",
    "[Due] L [at] LT" : "[مستحق في] L [عند] LT",
    "Successfully created the task." : "تم إنشاء المهمّة بنجاح.",
    "Could not update the task." : "لا يمكن تحديث المهمّة.",
    "Successfully updated the task." : "تم تحديث المهمّة بنجاح.",
    "An error occurred" : "طرأ هناك خطأ",
    "Create a task" : "أنشئ مهمّة",
    "Message from {author} in {conversationName}" : "رسالة من {author} في {conversationName}"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");

==> nextcloud-app-tasks-0.15.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/ar.js <==
OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "المهام القادمة",
    "Important" : "مهم",
    "Today" : "اليوم",
    "Week" : "أسبوع",
    "All" : "الكل",
    "Current" : "الحالي",
    "Completed" : "مكتمل",
    "Tasks" : "المهام",
    "The Tasks app for Nextcloud" : "تطبيق المهام لـ نكست كلاود",
    "Default list" : "القائمة الإفتراضية",
    "Hidden" : "مخفي",
    "Visible" : "مرئيّ",
    "Automatic" : "تلقائي",
    "Share with users or groups" : "شارك مع مستخدمين او مجموعات",
    "No users or groups" : "لا يوجد مستخدمين أو مجموعات",
    "Can edit" : "يمكن تعديله",
    "Unshare with {displayName}" : "الغاء المشاركة مع {displayName}",
    "Edit" : "تعديل",
    "Copy private link" : "نسخ الرابط الخاص",
    "Copied" : "نُسخت ",
    "Cannot copy" : "لا يمكن النسخ",
    "Export" : "تصدير",
    "Delete" : "حذف ",
    "Unshare" : "إلغاء المشاركة",
    "List name" : "قامة اسماء",
    "Calendar link copied to clipboard." : "تم نسخ رابط التقويم.",
    "Calendar link could not be copied to clipboard." : "لم نتمكن من نسخ رابط التقويم.",
    "The name \"{calendar}\" is already used." : "الإسم\"{calendar}\" يستخدم بالفعل.",
    "An empty name is not allowed." : "غير مسموح بإسم فارغ",
    "An error occurred, unable to delete the calendar." : "حدث خطأ، لا يمكن حذف التقويم.",
    "Trash bin" : "المهملات",
    "Name" : "الاسم",
    "Deleted" : "تم حذفه",
    "Restore" : "استعادة ",
    "Delete permanently" : "حذف بشكل دائم",
    "Empty trash bin" : "تفريغ سلة المهملات",
    "Untitled task" : "مهمة بدون اسم",
    "Untitled event" : "فعالية بدون اسم",
    "Untitled item" : "بند غير معنون",
    "Unknown calendar" : "تقويم غير معروف",
    "Select a calendar" : "اختر تقويم",
    "Set date" : "تعيين التاريخ",
    "Set time" : "تعيين الوقت",
    "Delete date" : "حذف التاريخ",
    "Click here to add a note." : "اضغط هنا لإضافة ملاحظة.",
    "Set value" : "تعيين القيمة",
    "Delete value" : "حذف القيمة",
    "Add this as a new tag" : "أضف هذا كوسم جديد",
    "Delete all completed tasks." : "حذف كل المهام المكتملة.",
    "Delete completed tasks." : "حذف المهام المكتملة.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "قد حذفت المهام المكتملة من \"{calendar}\".",
    "No errors" : "لا توجد أخطاء",
    "Open your browser console for more details" : "افتح مِعراض المتصفح للمزيد من التفاصيل",
    "Due date" : "تاريخ الانجاز",
    "Created date" : "تاريخ الإنشاء",
    "Last modified" : "آخر تعديل",
    "Completed date" : "تاريخ الإكتمال",
    "Alphabetically" : "أبجديا",
    "Delete task" : "حذف المهمّة",
    "[Yesterday]" : "[امس]",
    "[Today]" : "[اليوم]",
    "[Tomorrow]" : "[الغد]",
    "L [at] LT" : "L [عند] LT",
    "Create a new task" : "أنشئ مهمّة جديدة",
    "Cancel" : "إلغاء",
    "Create task" : "أنشئ المهمّة",
    "Close" : "إغلاق",
    "Tomorrow" : "غدا",
    "All day" : "اليوم بأكمله",
    "Edit title" : "تحرير العنوان",
    "Details" : "التفاصيل",
    "Notes" : "الملاحظات",
    "Reminders" : "تذكيرات",
    "Repeat" : "التكرار",
    "When shared show full event" : "عرض الحدث كاملاً عند مشاركته",
    "When shared show only busy" : "عرض مشغول عند مشاركة الحدث",
    "When shared hide this event" : "إخفاء الحدث عند مشاركته",
    "Canceled" : "ملغي",
    "[Due today]" : "[مستحق اليوم]",
    "[Due tomorrow]" : "[مطلوب غداً]",
    "[Due on] LL" : "[مستحق في] LL",
    "[Was due yesterday]" : "[كان مستحق بالأمس]",
    "[Was due on] LL" : "[كان مستحق في] LL",
    "[Was due today at] LT" : "[كان مستحق اليوم عند] LT",
    "[Due today at] LT" : "[مستحق اليوم عند] LT",
    "[Due tomorrow at] LT" : "[مطلوب غداً عند] LT",
    "[Due on] LL [at] LT" : "[مستحق في] LL [عند] LT",
    "[Was due yesterday at] LT" : "[كان مستحق بالأمس عند] LT",
    "[Was due on] LL [at] LT" : "[كان مستحق في] LL [عند] LT",
    "Set due date" : "تعيين تاريخ استحقاق",
    "{percent} % completed" : "{percent}% مكتمل",
    "No upcoming tasks" : "لا مهام قادمة ",
    "upcoming tasks" : "المهام القادمة",
    "No tasks today" : "لا مهام لليوم",
    "Mark as done" : "تمييز كمُنجز",
    "No due date assigned" : "لم يتم تعيين تاريخ استحقاق",
    "[Due yesterday]" : "[كان مستحق بالأمس]",
    "[Due] L" : "[مستحق في] L",
    "[Due yesterday at] LT" : "[كان مستحق بالأمس عند] LT",
    "[Due] L [at] LT" : "[مستحق في] L [عند] LT",
    "Successfully created the task." : "تم إنشاء المهمّة بنجاح.",
    "Could not update the task." : "لا يمكن تحديث المهمّة.",
    "Successfully updated the task." : "تم تحديث المهمّة بنجاح.",
    "An error occurred" : "طرأ هناك خطأ",
    "Create a task" : "أنشئ مهمّة",
    "Message from {author} in {conversationName}" : "رسالة من {author} في {conversationName}"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
